"""Data loaders - CSV and other structured data formats."""

from .csv import csv_to_pandas

__all__ = ["csv_to_pandas"]
